@@ -1,7 +1,10 @@
-import pooch
 import os
-from pyrregular.io_utils import load_from_file
+
+import pooch
+import xarray as xr
+
 from pyrregular.data_utils import get_project_root
+from pyrregular.io_utils import load_from_file
 
 REPOSITORY = pooch.create(
     path=pooch.os_cache("pyrregular"),
@@ -13,10 +16,7 @@ REPOSITORY.load_registry(get_project_root() / "registry.txt")
 
 
 def download_dataset_from_huggingface(
-        name,
-        use_api_token=False,
-        api_token=None,
-        progressbar=True
+    name, use_api_token=False, api_token=None, progressbar=True
 ):
     if use_api_token:
         if api_token is None:
@@ -31,12 +31,21 @@ def download_dataset_from_huggingface(
     return REPOSITORY.fetch(name, downloader=downloader)
 
 
-def load_dataset_from_huggingface(name, api_token=None):
+def load_dataset_from_file(name, api_token=None):
     if ".h5" not in name:
         name += ".h5"
     file = download_dataset_from_huggingface(name, api_token)
-    return load_from_file(file)
+    return file
+
+
+def load_dataset_from_huggingface(name, api_token=None):
+    return load_from_file(load_dataset_from_file(name, api_token))
+
+
+def load_dataset_from_huggingface_via_xarray(name, api_token=None):
+    return xr.load_dataset(load_dataset_from_file(name, api_token), engine="pyrregular")
 
 
 if __name__ == "__main__":
-    df = load_dataset_from_huggingface("Garment.h5")
+    pass
+    # df = load_dataset_from_huggingface("Garment.h5")
